@@ -173,7 +173,6 @@ class HelpFormatter:
     """
 
     def __init__(self, prog, indent_increment=2, max_help_position=24, width=None):
-
         # default setting for width
         if width is None:
             try:
@@ -268,7 +267,6 @@ class HelpFormatter:
 
     def add_argument(self, action):
         if action.help is not SUPPRESS:
-
             # find all invocations
             get_invocation = self._format_action_invocation
             invocations = [get_invocation(action)]
@@ -333,7 +331,6 @@ class HelpFormatter:
             # wrap the usage parts if it's too long
             text_width = self._width - self._current_indent
             if len(prefix) + len(usage) > text_width:
-
                 # break usage into wrappable parts
                 part_regexp = r"\(.*?\)+|\[.*?\]+|\S+"
                 opt_usage = format(optionals, groups)
@@ -424,7 +421,6 @@ class HelpFormatter:
         # collect all actions format strings
         parts = []
         for i, action in enumerate(actions):
-
             # suppressed arguments are marked with None
             # remove | separators for suppressed arguments
             if action.help is SUPPRESS:
@@ -986,11 +982,9 @@ class _VersionAction(Action):
 class _SubParsersAction(Action):
     class _ChoicesPseudoAction(Action):
         def __init__(self, name, help):
-            sup = super(_SubParsersAction._ChoicesPseudoAction, self)
-            sup.__init__(option_strings=[], dest=name, help=help)
+            super().__init__(option_strings=[], dest=name, help=help)
 
     def __init__(self, option_strings, prog, parser_class, dest=SUPPRESS, help=None, metavar=None):
-
         self._prog_prefix = prog
         self._parser_class = parser_class
         self._name_parser_map = {}
@@ -1286,7 +1280,6 @@ class _ActionsContainer:
         # map each action to its group
         group_map = {}
         for group in container._action_groups:
-
             # if a group with the title exists, use that, otherwise
             # create a new group matching the container's group
             if group.title not in title_group_map:
@@ -1376,7 +1369,6 @@ class _ActionsContainer:
             raise ValueError(msg % self.conflict_handler)
 
     def _check_conflict(self, action):
-
         # find all options that conflict with this option
         confl_optionals = []
         for option_string in action.option_strings:
@@ -1397,7 +1389,6 @@ class _ActionsContainer:
     def _handle_conflict_resolve(self, action, conflicting_actions):
         # remove all conflicting options
         for option_string, action in conflicting_actions:
-
             # remove the conflicting option
             action.option_strings.remove(option_string)
             self._option_string_actions.pop(option_string, None)
@@ -1491,7 +1482,6 @@ class ArgumentParser(_AttributeHolder, _ActionsContainer):
         conflict_handler="error",
         add_help=True,
     ):
-
         if version is not None:
             import warnings
 
@@ -1697,7 +1687,6 @@ class ArgumentParser(_AttributeHolder, _ActionsContainer):
         arg_string_pattern_parts = []
         arg_strings_iter = iter(arg_strings)
         for i, arg_string in enumerate(arg_strings_iter):
-
             # all args after -- are non-options
             if arg_string == "--":
                 arg_string_pattern_parts.append("-")
@@ -1744,7 +1733,6 @@ class ArgumentParser(_AttributeHolder, _ActionsContainer):
 
         # function to convert arg_strings into an optional action
         def consume_optional(start_index):
-
             # get the optional identified at this index
             option_tuple = option_string_indices[start_index]
             action, option_string, explicit_arg = option_tuple
@@ -1754,7 +1742,6 @@ class ArgumentParser(_AttributeHolder, _ActionsContainer):
             match_argument = self._match_argument
             action_tuples = []
             while True:
-
                 # if we found no optional action, skip it
                 if action is None:
                     extras.append(arg_strings[start_index])
@@ -1847,7 +1834,6 @@ class ArgumentParser(_AttributeHolder, _ActionsContainer):
         else:
             max_option_string_index = -1
         while start_index <= max_option_string_index:
-
             # consume any Positionals preceding the next option
             next_option_string_index = min(index for index in option_string_indices if index >= start_index)
             if start_index != next_option_string_index:
@@ -1909,7 +1895,6 @@ class ArgumentParser(_AttributeHolder, _ActionsContainer):
         # expand arguments referencing files
         new_arg_strings = []
         for arg_string in arg_strings:
-
             # for regular arguments, just add them back into the list
             if arg_string[0] not in self.fromfile_prefix_chars:
                 new_arg_strings.append(arg_string)
