@@ -80,6 +80,7 @@ offset+16+B:  ...          (B bytes) value for interval 2
 ...          ...           ...
 ============ ===========   =================================================
 """
+
 import os.path
 import sys
 from bisect import (
@@ -157,7 +158,7 @@ def bin_for_range(start, end, offsets=None):
         else:
             start_bin >>= BIN_NEXT_SHIFT
             end_bin >>= BIN_NEXT_SHIFT
-    raise Exception("Interval (%d,%d) out of range")
+    raise Exception("Interval (%d,%d) out of range" % (start, end))
 
 
 class AbstractMultiIndexedAccess:
