@@ -5,7 +5,7 @@ Complement a set of intervals.
 from bx.bitset import MAX
 from bx.intervals.io import (
     BitsetSafeReaderWrapper,
-    GenomicInterval
+    GenomicInterval,
 )
 from bx.intervals.operations import bits_set_in_range
 
@@ -25,20 +25,35 @@ def complement(reader, lens):
         try:
             # Write the intervals
             for start, end in out_intervals:
-                fields = ["." for x in range(max(complement_reader.chrom_col, complement_reader.start_col, complement_reader.end_col)+1)]
+                fields = [
+                    "."
+                    for x in range(
+                        max(complement_reader.chrom_col, complement_reader.start_col, complement_reader.end_col) + 1
+                    )
+                ]
                 # default the column to a + if it exists
                 if complement_reader.strand_col < len(fields) and complement_reader.strand_col >= 0:
                     fields[complement_reader.strand_col] = "+"
                 fields[complement_reader.chrom_col] = chrom
                 fields[complement_reader.start_col] = start
                 fields[complement_reader.end_col] = end
-                new_interval = GenomicInterval(complement_reader, fields, complement_reader.chrom_col, complement_reader.start_col, complement_reader.end_col, complement_reader.strand_col, "+")
+                new_interval = GenomicInterval(
+                    complement_reader,
+                    fields,
+                    complement_reader.chrom_col,
+                    complement_reader.start_col,
+                    complement_reader.end_col,
+                    complement_reader.strand_col,
+                    "+",
+                )
                 yield new_interval
         except IndexError as e:
             complement_reader.skipped += 1
             # no reason to stuff an entire bad file into memmory
             if complement_reader.skipped < 10:
-                complement_reader.skipped_lines.append((complement_reader.linenum, complement_reader.current_line, str(e)))
+                complement_reader.skipped_lines.append(
+                    (complement_reader.linenum, complement_reader.current_line, str(e))
+                )
             continue
 
 
