@@ -65,7 +65,6 @@ qScoresExpected = "4.1106 0.7810"
 
 class PWMTestCase(unittest.TestCase):
     def testReader(self):
-
         # test basic format: i.e. for jaspar
         wms = [
             wm for wm in pwm.Reader(StringIO(basicPwm), format="basic", background=background, score_correction=False)
@@ -87,7 +86,7 @@ class PWMTestCase(unittest.TestCase):
         assert f"{dScores[0][0]:.4f} {dScores[0][1]:.4f} {dScores[1][0]:.4f} {dScores[1][1]:.4f}" == dScoresExpected
 
         qdSeq = []
-        for (ix, nt) in enumerate(dSeq):
+        for ix, nt in enumerate(dSeq):
             qdSeq.append(dict())
             qdSeq[ix][nt] = 1.0
         qScores = wm.score_seq(qdSeq)
