@@ -10,22 +10,23 @@ test_nib = "test_data/seq_tests/test.nib"
 
 # Same sequence data as stored in test.nib
 
-valid_seq = "TGGAGGCATTTGTGATTCAATAGATGCAGAAAGAAACCTTCCTAGAGCTG" \
-    + "GCGTTCTCTAACTAAAAGTGGAAAGTTCTGAGGAATGAGGACTGTTATAA" \
-    + "ATCCCACCCCACACCGCACCTTCTCCAGGGAAGTTTCATGGCCGTGAAGA" \
-    + "GGACAGAAAGTGAGAACCAAGATggaactgaataaacaagcttcacactg" \
-    + "ttagtttccccatatgcttaccttcccacagatgccaaccttggaggcct" \
-    + "aagaggcctagaatattatcctttgtctgatcatttctctacaaatttat" \
-    + "tgttctttgttaagatgctacataagcccaaattctaaccacccctttga" \
+valid_seq = (
+    "TGGAGGCATTTGTGATTCAATAGATGCAGAAAGAAACCTTCCTAGAGCTG"
+    + "GCGTTCTCTAACTAAAAGTGGAAAGTTCTGAGGAATGAGGACTGTTATAA"
+    + "ATCCCACCCCACACCGCACCTTCTCCAGGGAAGTTTCATGGCCGTGAAGA"
+    + "GGACAGAAAGTGAGAACCAAGATggaactgaataaacaagcttcacactg"
+    + "ttagtttccccatatgcttaccttcccacagatgccaaccttggaggcct"
+    + "aagaggcctagaatattatcctttgtctgatcatttctctacaaatttat"
+    + "tgttctttgttaagatgctacataagcccaaattctaaccacccctttga"
     + "gttacccatcatcaagtttctcccatgtg"
+)
 
 valid_seq_len = len(valid_seq)
 
 
 class NIBTestCase(unittest.TestCase):
-
     def test_get(self):
-        nibfile = nib.NibFile(open(test_nib, 'rb'))
+        nibfile = nib.NibFile(open(test_nib, "rb"))
         # Try all combinations of even / odd boundaries
         check_get(nibfile, 0, 10)
         check_get(nibfile, 1, 10)
@@ -44,4 +45,4 @@ class NIBTestCase(unittest.TestCase):
 
 
 def check_get(nibfile, start, len):
-    assert nibfile.get(start, len) == valid_seq[start:start+len]
+    assert nibfile.get(start, len) == valid_seq[start : start + len]
