@@ -39,6 +39,7 @@ variable (in which case it is an error).
 Recognized properties (at present only one):
   - codebook: A string in qdna code file format (see QdnaCodebook class for details).
 """
+
 import struct
 from io import StringIO
 
@@ -194,7 +195,7 @@ class QdnaCodebook:
         alphabet = "ACGT"
         codeToProbs = {}
 
-        for (lineNum, line) in enumerate(codeF):
+        for lineNum, line in enumerate(codeF):
             lineNum += 1
             line = line.rstrip()
             stripped = line.strip()
