@@ -18,7 +18,7 @@ from numpy import (
     int32,
     isnan,
     savetxt,
-    zeros
+    zeros,
 )
 
 from bx.bbi.bigwig_file import BigWigFile
@@ -26,8 +26,8 @@ from bx.intervals.io import GenomicIntervalReader
 
 bw = BigWigFile(open(sys.argv[1]))
 padding = int(sys.argv[2])
-totals = zeros(padding*2, dtype=float64)
-valid = zeros(padding*2, dtype=int32)
+totals = zeros(padding * 2, dtype=float64)
+valid = zeros(padding * 2, dtype=int32)
 
 for interval in GenomicIntervalReader(sys.stdin):
     center = floor((interval.start + interval.end) / 2)
@@ -36,6 +36,6 @@ for interval in GenomicIntervalReader(sys.stdin):
     invalid = isnan(values)
     values[invalid] = 0
     totals += values
-    valid += (~ invalid)
+    valid += ~invalid
 
-savetxt(sys.stdout, totals/valid)
+savetxt(sys.stdout, totals / valid)
