@@ -35,9 +35,9 @@ narrowPeak_t = np.dtype(
         ("id", np.str_, 100),
         ("score", np.int64),
         ("strand", np.str_, 1),
-        ("signalValue", np.float),
-        ("pValue", np.float),
-        ("qValue", np.float),
+        ("signalValue", float),
+        ("pValue", float),
+        ("qValue", float),
         ("peak", np.int64),
     ]
 )
@@ -134,7 +134,7 @@ def union_elements(elements):
 
     unioned_elements = []
     for ch, chgrp in groupby(elements, key=itemgetter(0)):
-        for (s, e) in elem_u(np.array([itemgetter(1, 2)(_) for _ in chgrp], dtype=np.uint)):
+        for s, e in elem_u(np.array([itemgetter(1, 2)(_) for _ in chgrp], dtype=np.uint)):
             if s < e:
                 unioned_elements.append((ch, s, e, el_id))
     assert len(unioned_elements) <= len(elements)
