@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/env python
 
 """
 Read a compressed file as created by 'lzop' from stdin and write a table to
@@ -7,12 +7,11 @@ compressed block.
 
 usage: %prog < FILENAME.lzo > FILENAME.lzot
 """
-from __future__ import print_function
 
 import struct
 import sys
 
-MAGIC = "\x89\x4c\x5a\x4f\x00\x0d\x0a\x1a\x0a"
+MAGIC = b"\x89\x4c\x5a\x4f\x00\x0d\x0a\x1a\x0a"
 
 F_ADLER32_D = 0x00000001
 F_ADLER32_C = 0x00000002
@@ -28,7 +27,7 @@ assert struct.calcsize("!H") == 2
 assert struct.calcsize("!I") == 4
 
 
-class UnpackWrapper(object):
+class UnpackWrapper:
     def __init__(self, file):
         self.file = file
 
@@ -41,7 +40,12 @@ class UnpackWrapper(object):
 
 
 def main():
-    f = UnpackWrapper(sys.stdin)
+    try:
+        binary_stdin = sys.stdin.buffer
+    except AttributeError:
+        # Python 2
+        binary_stdin = sys.stdin
+    f = UnpackWrapper(binary_stdin)
     # Read header
     magic = f.read(9)
     assert magic == MAGIC, "Not LZOP file"
@@ -53,9 +57,9 @@ def main():
     assert 1 <= method <= 3, "Only LZO compression is currently supported"
     f.get("!B")  # level
     flags = f.get("!I")
-    assert not(flags & F_H_FILTER), "LZOP filters not supported"
-    has_compressed_crc = (flags & F_CRC32_C or flags & F_ADLER32_C)
-    has_uncompressed_crc = (flags & F_CRC32_D or flags & F_ADLER32_D)
+    assert not (flags & F_H_FILTER), "LZOP filters not supported"
+    has_compressed_crc = flags & F_CRC32_C or flags & F_ADLER32_C
+    has_uncompressed_crc = flags & F_CRC32_D or flags & F_ADLER32_D
     f.get("!I")  # mode
     f.get("!I")  # time
     f.get("!I")  # time_offset
@@ -75,8 +79,7 @@ def main():
         size = f.get("!I")
         if size == 0:
             break
-        assert not(expect_no_more), \
-            "Encountered an undersized block that was not the last block"
+        assert not (expect_no_more), "Encountered an undersized block that was not the last block"
         if block_size is None:
             print("s", size)
             block_size = size
@@ -90,8 +93,7 @@ def main():
             f.get("!I")  # compressed_crc
         print("o", f.file.tell(), compressed_size, size)
         compressed_data = f.read(compressed_size)
-        assert len(compressed_data) == compressed_size, \
-            "EOF reading compressed data"
+        assert len(compressed_data) == compressed_size, "EOF reading compressed data"
 
 
 if __name__ == "__main__":
